Introduce new split:devm_thermal_zone_of_sensor_register_params()
function, which allows passing struct thermal_zone_params into it
and convert original devm_thermal_zone_of_sensor_register() to call
it with params set to NULL.

Signed-off-by: Marek Vasut <[email protected]>
Cc: Daniel Lezcano <[email protected]>
Cc: Eduardo Valentin <[email protected]>
Cc: Wolfram Sang <[email protected]>
Cc: Zhang Rui <[email protected]>
Cc: [email protected]
To: [email protected]
---
V2: Add EXPORT_SYMBOL_GPL() to fix build as a module
---
 drivers/thermal/of-thermal.c | 43 +++++++++++++++++++++++++++++++-----
 include/linux/thermal.h      | 13 +++++++++++
 2 files changed, 50 insertions(+), 6 deletions(-)

diff --git a/include/linux/thermal.h b/include/linux/thermal.h
index 922034eae74b..a9e7bdeea1bb 100644
--- a/include/linux/thermal.h
+++ b/include/linux/thermal.h
@@ -387,6 +387,10 @@ void thermal_zone_of_sensor_unregister(struct device *dev,
 struct thermal_zone_device *devm_thermal_zone_of_sensor_register(
                struct device *dev, int id, void *data,
                const struct thermal_zone_of_device_ops *ops);
+struct thermal_zone_device *devm_thermal_zone_of_sensor_register_params(
+               struct device *dev, int id, void *data,
+               const struct thermal_zone_of_device_ops *ops,
+               struct thermal_zone_params *tzp);
 void devm_thermal_zone_of_sensor_unregister(struct device *dev,
                                            struct thermal_zone_device *tz);
 #else
@@ -418,6 +422,15 @@ static inline struct thermal_zone_device 
*devm_thermal_zone_of_sensor_register(
        return ERR_PTR(-ENODEV);
 }
 
+static inline struct thermal_zone_device *
+       devm_thermal_zone_of_sensor_register_params(
+               struct device *dev, int id, void *data,
+               const struct thermal_zone_of_device_ops *ops,
+               struct thermal_zone_params *tzp)
+{
+       return ERR_PTR(-ENODEV);
+}
+
 static inline
 void devm_thermal_zone_of_sensor_unregister(struct device *dev,
                                            struct thermal_zone_device *tz)
diff --git a/drivers/thermal/of-thermal.c b/drivers/thermal/of-thermal.c
index 1fb450d02ab5..e1a303a5698c 100644
--- a/drivers/thermal/of-thermal.c
+++ b/drivers/thermal/of-thermal.c
@@ -638,8 +638,8 @@ static int devm_thermal_zone_of_sensor_match(struct device 
*dev, void *res,
 }
 
 /**
  * devm_thermal_zone_of_sensor_register - Resource managed version of
  *                             thermal_zone_of_sensor_register()
  * @dev: a valid struct device pointer of a sensor device. Must contain
  *       a valid .of_node, for the sensor node.
  * @sensor_id: a sensor identifier, in case the sensor IP has more
@@ -647,8 +647,9 @@ static int devm_thermal_zone_of_sensor_match(struct device 
*dev, void *res,
  * @data: a private pointer (owned by the caller) that will be passed
  *       back, when a temperature reading is needed.
  * @ops: struct thermal_zone_of_device_ops *. Must contain at least .get_temp.
+ * @tzp: thermal zone platform parameters
  *
  * Refer thermal_zone_of_sensor_register() for more details.
  *
  * Return: On success returns a valid struct thermal_zone_device,
  * otherwise, it returns a corresponding ERR_PTR(). Caller must
@@ -656,9 +657,10 @@ static int devm_thermal_zone_of_sensor_match(struct device 
*dev, void *res,
  * Registered thermal_zone_device device will automatically be
  * released when device is unbounded.
  */
-struct thermal_zone_device *devm_thermal_zone_of_sensor_register(
+struct thermal_zone_device *devm_thermal_zone_of_sensor_register_params(
        struct device *dev, int sensor_id,
-       void *data, const struct thermal_zone_of_device_ops *ops)
+       void *data, const struct thermal_zone_of_device_ops *ops,
+       struct thermal_zone_params *tzp)
 {
        struct thermal_zone_device **ptr, *tzd;
 
@@ -667,7 +669,8 @@ struct thermal_zone_device 
*devm_thermal_zone_of_sensor_register(
        if (!ptr)
                return ERR_PTR(-ENOMEM);
 
-       tzd = thermal_zone_of_sensor_register(dev, sensor_id, data, ops);
+       tzd = thermal_zone_of_sensor_register_params(dev, sensor_id, data,
+                                                    ops, tzp);
        if (IS_ERR(tzd)) {
                devres_free(ptr);
                return tzd;
@@ -678,6 +681,34 @@ struct thermal_zone_device 
*devm_thermal_zone_of_sensor_register(
 
        return tzd;
 }
+EXPORT_SYMBOL_GPL(devm_thermal_zone_of_sensor_register_params);
+
+/**
+ * devm_thermal_zone_of_sensor_register - Resource managed version of
+ *                             thermal_zone_of_sensor_register()
+ * @dev: a valid struct device pointer of a sensor device. Must contain
+ *       a valid .of_node, for the sensor node.
+ * @sensor_id: a sensor identifier, in case the sensor IP has more
+ *            than one sensors
+ * @data: a private pointer (owned by the caller) that will be passed
+ *       back, when a temperature reading is needed.
+ * @ops: struct thermal_zone_of_device_ops *. Must contain at least .get_temp.
+ *
+ * Refer thermal_zone_of_sensor_register() for more details.
+ *
+ * Return: On success returns a valid struct thermal_zone_device,
+ * otherwise, it returns a corresponding ERR_PTR(). Caller must
+ * check the return value with help of IS_ERR() helper.
+ * Registered thermal_zone_device device will automatically be
+ * released when device is unbounded.
+ */
+struct thermal_zone_device *devm_thermal_zone_of_sensor_register(
+       struct device *dev, int sensor_id,
+       void *data, const struct thermal_zone_of_device_ops *ops)
+{
+       return devm_thermal_zone_of_sensor_register_params(dev, sensor_id,
+                                                          data, ops, NULL);
+}
 EXPORT_SYMBOL_GPL(devm_thermal_zone_of_sensor_register);
 
 /**
@@ -638,8 +638,8 @@ static int devm_thermal_zone_of_sensor_match(struct device 
 
 /**
- * devm_thermal_zone_of_sensor_register - Resource managed version of
- *                             thermal_zone_of_sensor_register()
+ * devm_thermal_zone_of_sensor_register_params - Resource managed version of
+ *                             thermal_zone_of_sensor_register_params()
  * @dev: a valid struct device pointer of a sensor device. Must contain
  *       a valid .of_node, for the sensor node.
@@ -647,8 +647,9 @@ static int devm_thermal_zone_of_sensor_match(struct device 
  *
- * Refer thermal_zone_of_sensor_register() for more details.
+ * Refer thermal_zone_of_sensor_register_params() for more details.
  *
  * Return: On success returns a valid struct thermal_zone_device,
-- 
2.18.0

Reply via email to